package com.gxzc.zen.web.sys.controller

import com.baomidou.kisso.annotation.Action
import com.baomidou.kisso.annotation.Login
import com.gxzc.zen.api.sys.model.SysDic
import com.gxzc.zen.api.sys.service.ISysDicService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.config.response.annotation.ZenResponseFilter
import com.gxzc.zen.common.dto.ResponseDto
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import java.net.URI

/**
 * 系统参数 控制器
 * @author NorthLan
 * @date 2018/3/9
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("/sys/dic")
class SysDicController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(SysDicController::class.java)
    }

    @Autowired
    private lateinit var sysDicService: ISysDicService

    @GetMapping("/list")
    @Login(action = Action.Skip)
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun getList(): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysDicService.getListCacheable()
        })
    }

    @GetMapping("{id}")
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun getById(@PathVariable id: Long): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysDicService.selectById(id)
        })
    }

    @GetMapping("keys/{key}")
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun getByKey(@PathVariable key: String): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = sysDicService.getListByKey(key)
        })
    }

    @PutMapping
    @ZenResponseFilter(type = SysDic::class, filter = ["createBy", "updateBy", "createTime", "updateTime"])
    fun putDic(@RequestBody data: SysDic): ResponseEntity<*> {
        return if (data.id == null) {
            // insert
            sysDicService.insertCacheable(data.apply { id = null })
            ResponseEntity.created(URI.create("/sys/dic/${data.id}")).body(ResponseDto()) // 201
        } else {
            // update
            ResponseEntity.ok(ResponseDto().apply {
                this.data = sysDicService.modifySysDic(data) // 200
            })
        }
    }

    @DeleteMapping("{id}")
    fun deleteDic(@PathVariable id: Long): ResponseEntity<*> {
        // 物理删除数据
        sysDicService.physicalDeleteCacheable(id)
        return ResponseEntity.ok(ResponseDto())
    }
}